==> openshift-model-5.7.3-sources.jar: io/fabric8/openshift/api/model/GenericWebHookCauseBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class GenericWebHookCauseBuilder extends io.fabric8.openshift.api.model.GenericWebHookCauseFluentImpl<io.fabric8.openshift.api.model.GenericWebHookCauseBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.GenericWebHookCause,io.fabric8.openshift.api.model.GenericWebHookCauseBuilder>{
  public GenericWebHookCauseBuilder() {
    this(false);
  }
  public GenericWebHookCauseBuilder(java.lang.Boolean validationEnabled) {
    this(new GenericWebHookCause(), validationEnabled);
  }
  public GenericWebHookCauseBuilder(io.fabric8.openshift.api.model.GenericWebHookCauseFluent<?> fluent) {
    this(fluent, false);
  }
  public GenericWebHookCauseBuilder(io.fabric8.openshift.api.model.GenericWebHookCauseFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new GenericWebHookCause(), validationEnabled);
  }
  public GenericWebHookCauseBuilder(io.fabric8.openshift.api.model.GenericWebHookCauseFluent<?> fluent,io.fabric8.openshift.api.model.GenericWebHookCause instance) {
    this(fluent, instance, false);
  }
  public GenericWebHookCauseBuilder(io.fabric8.openshift.api.model.GenericWebHookCauseFluent<?> fluent,io.fabric8.openshift.api.model.GenericWebHookCause instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withRevision(instance.getRevision()); 
    fluent.withSecret(instance.getSecret()); 
    this.validationEnabled = validationEnabled; 
  }
  public GenericWebHookCauseBuilder(io.fabric8.openshift.api.model.GenericWebHookCause instance) {
    this(instance,false);
  }
  public GenericWebHookCauseBuilder(io.fabric8.openshift.api.model.GenericWebHookCause instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withRevision(instance.getRevision()); 
    this.withSecret(instance.getSecret()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.GenericWebHookCauseFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.GenericWebHookCause build() {
    GenericWebHookCause buildable = new GenericWebHookCause(fluent.getRevision(),fluent.getSecret());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    GenericWebHookCauseBuilder that = (GenericWebHookCauseBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.12.0-sources.jar: io/fabric8/openshift/api/model/GenericWebHookCauseBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class GenericWebHookCauseBuilder extends io.fabric8.openshift.api.model.GenericWebHookCauseFluentImpl<io.fabric8.openshift.api.model.GenericWebHookCauseBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.GenericWebHookCause,io.fabric8.openshift.api.model.GenericWebHookCauseBuilder>{
  public GenericWebHookCauseBuilder() {
    this(false);
  }
  public GenericWebHookCauseBuilder(java.lang.Boolean validationEnabled) {
    this(new GenericWebHookCause(), validationEnabled);
  }
  public GenericWebHookCauseBuilder(io.fabric8.openshift.api.model.GenericWebHookCauseFluent<?> fluent) {
    this(fluent, false);
  }
  public GenericWebHookCauseBuilder(io.fabric8.openshift.api.model.GenericWebHookCauseFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new GenericWebHookCause(), validationEnabled);
  }
  public GenericWebHookCauseBuilder(io.fabric8.openshift.api.model.GenericWebHookCauseFluent<?> fluent,io.fabric8.openshift.api.model.GenericWebHookCause instance) {
    this(fluent, instance, false);
  }
  public GenericWebHookCauseBuilder(io.fabric8.openshift.api.model.GenericWebHookCauseFluent<?> fluent,io.fabric8.openshift.api.model.GenericWebHookCause instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withRevision(instance.getRevision()); 
    fluent.withSecret(instance.getSecret()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public GenericWebHookCauseBuilder(io.fabric8.openshift.api.model.GenericWebHookCause instance) {
    this(instance,false);
  }
  public GenericWebHookCauseBuilder(io.fabric8.openshift.api.model.GenericWebHookCause instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withRevision(instance.getRevision()); 
    this.withSecret(instance.getSecret()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.GenericWebHookCauseFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.GenericWebHookCause build() {
    GenericWebHookCause buildable = new GenericWebHookCause(fluent.getRevision(),fluent.getSecret());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    GenericWebHookCauseBuilder that = (GenericWebHookCauseBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
